package com.xinelu.manage.service.servicepackagecontent.impl;

import com.xinelu.manage.domain.servicepackagecontent.ServicePackageContent;
import com.xinelu.manage.mapper.servicepackagecontent.ServicePackageContentMapper;
import com.xinelu.manage.service.servicepackagecontent.IServicePackageContentService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.time.LocalDateTime;
import java.util.List;

/**
 * 服务包内容Service业务层处理
 *
 * @author xinelu
 * @date 2024-03-04
 */
@Service
public class ServicePackageContentServiceImpl implements IServicePackageContentService {
    @Resource
    private ServicePackageContentMapper servicePackageContentMapper;

    /**
     * 查询服务包内容
     *
     * @param id 服务包内容主键
     * @return 服务包内容
     */
    @Override
    public ServicePackageContent selectServicePackageContentById(Long id) {
        return servicePackageContentMapper.selectServicePackageContentById(id);
    }

    /**
     * 查询服务包内容列表
     *
     * @param servicePackageContent 服务包内容
     * @return 服务包内容
     */
    @Override
    public List<ServicePackageContent> selectServicePackageContentList(ServicePackageContent servicePackageContent) {
        return servicePackageContentMapper.selectServicePackageContentList(servicePackageContent);
    }

    /**
     * 新增服务包内容
     *
     * @param servicePackageContent 服务包内容
     * @return 结果
     */
    @Override
    public int insertServicePackageContent(ServicePackageContent servicePackageContent) {
        servicePackageContent.setCreateTime(LocalDateTime.now());
        return servicePackageContentMapper.insertServicePackageContent(servicePackageContent);
    }

    /**
     * 修改服务包内容
     *
     * @param servicePackageContent 服务包内容
     * @return 结果
     */
    @Override
    public int updateServicePackageContent(ServicePackageContent servicePackageContent) {
        servicePackageContent.setUpdateTime(LocalDateTime.now());
        return servicePackageContentMapper.updateServicePackageContent(servicePackageContent);
    }

    /**
     * 批量删除服务包内容
     *
     * @param ids 需要删除的服务包内容主键
     * @return 结果
     */
    @Override
    public int deleteServicePackageContentByIds(Long[] ids) {
        return servicePackageContentMapper.deleteServicePackageContentByIds(ids);
    }

    /**
     * 删除服务包内容信息
     *
     * @param id 服务包内容主键
     * @return 结果
     */
    @Override
    public int deleteServicePackageContentById(Long id) {
        return servicePackageContentMapper.deleteServicePackageContentById(id);
    }
}
